@@ -2,7 +2,6 @@ r"""
 模块：异常库
 功能：定义一些常见错误
 项目GitHub地址：https://github.com/Passkou/bilibili_api
-项目主页：https://passkou.com/bilibili_api
   _____                _____    _____   _  __   ____    _    _
  |  __ \      /\      / ____|  / ____| | |/ /  / __ \  | |  | |
  | |__) |    /  \    | (___   | (___   | ' /  | |  | | | |  | |
@@ -51,6 +50,10 @@ class LiveException(BilibiliApiException):
     def __init__(self, msg: str):
         super().__init__(msg)
 
+class UploadException(BilibiliApiException):
+    def __init__(self, msg: str):
+        super().__init__(msg)
+
 """
 奇怪的异常增加了！
 """
\ No newline at end of file
