@@ -2,7 +2,6 @@ r"""
 模块：user
 功能：获取用户各种信息以及操作用户
 项目GitHub地址：https://github.com/Passkou/bilibili_api
-项目主页：https://passkou.com/bilibili_api
   _____                _____    _____   _  __   ____    _    _
  |  __ \      /\      / ____|  / ____| | |/ /  / __ \  | |  | |
  | |__) |    /  \    | (___   | (___   | ' /  | |  | | | |  | |
@@ -12,6 +11,7 @@ r"""
 """
 import json
 from . import utils, exceptions, common
+import time
 
 API = utils.get_api()
 
@@ -678,7 +678,11 @@ def send_msg(uid: int, text: str, self_uid: int = None, verify: utils.Verify = N
         "msg[msg_type]": 1,
         "msg[msg_status]": 0,
         "msg[content]": json.dumps({"content": text}),
-        "csrf_token": verify.csrf
+        "msg[dev_id]": "1369CA35-1771-4B80-B6D4-D7EB975B7F8A",
+        "msg[new_face_version]": "0",
+        "msg[timestamp]": int(time.time()),
+        "csrf_token": verify.csrf,
+        "csrf": verify.csrf
     }
     data = utils.post(url=api["url"], data=data, cookies=verify.get_cookies())
     return data
