@@ -2,7 +2,6 @@ r"""
 模块：video
 功能：获取视频各种信息以及操作视频
 项目GitHub地址：https://github.com/Passkou/bilibili_api
-项目主页：https://passkou.com/bilibili_api
    _____                _____    _____   _  __   ____    _    _
  |  __ \      /\      / ____|  / ____| | |/ /  / __ \  | |  | |
  | |__) |    /  \    | (___   | (___   | ' /  | |  | | | |  | |
@@ -425,6 +424,8 @@ def get_danmaku(bvid: str = None, aid: int = None, page: int = 0,
             data = con
             danmakus = []
             offset = 0
+            if data == b'\x10\x01':
+                raise exceptions.BilibiliApiException(bvid + '视频弹幕已关闭')
             while offset < len(data):
                 if data[offset] == 0x0a:
                     dm = utils.Danmaku('')
@@ -635,7 +636,7 @@ def send_danmaku(danmaku: utils.Danmaku, page: int = 0, bvid: str = None, aid: i
 
     page_info = get_pages(bvid, aid, verify)
     oid = page_info[page]["cid"]
-    api = API["video"]["operate"]["send_danmaku"]
+    api = API["video"]["danmaku"]["send_danmaku"]
     if danmaku.is_sub:
         pool = 1
     else:
